==> sui-tool-app-1.4.0.tgz: package/lib/biometric.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { NativeBiometric } from 'capacitor-native-biometric';
export var isBiometricLoginAvailable = function isBiometricLoginAvailable() {
  return NativeBiometric.isAvailable();
};
export var getBiometricLoginCredentials = /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
    var domain, reason, title, subtitle, description, biometrics, credentials;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          domain = _ref.domain, reason = _ref.reason, title = _ref.title, subtitle = _ref.subtitle, description = _ref.description;
          _context.next = 3;
          return NativeBiometric.isAvailable();
        case 3:
          biometrics = _context.sent;
          if (!biometrics.isAvailable) {
            _context.next = 11;
            break;
          }
          _context.next = 7;
          return NativeBiometric.getCredentials({
            server: domain
          });
        case 7:
          credentials = _context.sent;
          _context.next = 10;
          return NativeBiometric.verifyIdentity({
            reason: reason,
            title: title,
            subtitle: subtitle,
            description: description
          });
        case 10:
          return _context.abrupt("return", credentials);
        case 11:
          return _context.abrupt("return", null);
        case 12:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return function getBiometricLoginCredentials(_x) {
    return _ref2.apply(this, arguments);
  };
}();
export var setBiometricLoginCredentials = /*#__PURE__*/function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(_ref3) {
    var username, password, domain;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) switch (_context2.prev = _context2.next) {
        case 0:
          username = _ref3.username, password = _ref3.password, domain = _ref3.domain;
          _context2.next = 3;
          return NativeBiometric.setCredentials({
            username: username,
            password: password,
            server: domain
          });
        case 3:
        case "end":
          return _context2.stop();
      }
    }, _callee2);
  }));
  return function setBiometricLoginCredentials(_x2) {
    return _ref4.apply(this, arguments);
  };
}();

==> sui-tool-app-1.8.0.tgz: package/lib/biometric.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { NativeBiometric } from '@capgo/capacitor-native-biometric';

// Delete user's credentials
/* NativeBiometric.deleteCredentials({
  server: "www.example.com",
}).then(); */

export var isBiometricLoginAvailable = function isBiometricLoginAvailable() {
  return NativeBiometric.isAvailable();
};
export var getBiometricLoginCredentials = /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
    var domain, reason, title, subtitle, description, biometrics, verified, credentials;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          domain = _ref.domain, reason = _ref.reason, title = _ref.title, subtitle = _ref.subtitle, description = _ref.description;
          _context.next = 3;
          return NativeBiometric.isAvailable();
        case 3:
          biometrics = _context.sent;
          if (biometrics.isAvailable) {
            _context.next = 6;
            break;
          }
          return _context.abrupt("return", null);
        case 6:
          _context.next = 8;
          return NativeBiometric.verifyIdentity({
            reason: reason,
            title: title,
            subtitle: subtitle,
            description: description
          }).then(function () {
            return true;
          }).catch(function () {
            return false;
          });
        case 8:
          verified = _context.sent;
          if (verified) {
            _context.next = 11;
            break;
          }
          return _context.abrupt("return", null);
        case 11:
          _context.next = 13;
          return NativeBiometric.getCredentials({
            server: domain
          });
        case 13:
          credentials = _context.sent;
          return _context.abrupt("return", credentials);
        case 15:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return function getBiometricLoginCredentials(_x) {
    return _ref2.apply(this, arguments);
  };
}();
export var setBiometricLoginCredentials = /*#__PURE__*/function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(_ref3) {
    var username, password, domain, biometrics;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) switch (_context2.prev = _context2.next) {
        case 0:
          username = _ref3.username, password = _ref3.password, domain = _ref3.domain;
          _context2.next = 3;
          return NativeBiometric.isAvailable();
        case 3:
          biometrics = _context2.sent;
          if (biometrics.isAvailable) {
            _context2.next = 6;
            break;
          }
          return _context2.abrupt("return");
        case 6:
          NativeBiometric.deleteCredentials({
            server: domain
          }).then();
          _context2.next = 9;
          return NativeBiometric.setCredentials({
            username: username,
            password: password,
            server: domain
          }).then();
        case 9:
        case "end":
          return _context2.stop();
      }
    }, _callee2);
  }));
  return function setBiometricLoginCredentials(_x2) {
    return _ref4.apply(this, arguments);
  };
}();
